{% if domain != None %}
    {% set title = domain.split('://')[1] %}
    {% set title = title.split(':')[0] %}
{% else %}
    {% set title = "urlshrink" %}
{% endif %}

{% set deleteModalId = "deleteModal" %}
{% set statsModalId = "statsModal" %}
{% set qrCodeId = "qrCode" %}

{% from "navbar.html" import navbar with context %}

<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>{{ title }}</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/bulma/0.9.2/css/bulma.min.css" rel="stylesheet">
    <style>
        .center {
          margin : 0 auto;
          text-align : center;
        }
    </style>
  </head>
  <body>
    {{ navbar() }}
    {% block body %}{% endblock %}
  </body>
  {% block footer %}{% endblock %}
</html>