{% extends "base.html" %}

{% block body %}
<div class="container content">
    {% if error is defined %}
    <article class="message is-warning">
      <div class="message-header">
        <p>Warning</p>
        <button class="delete" aria-label="delete"></button>
      </div>
      <div class="message-body">
        {{ error }}
      </div>
    </article>
    {% endif %}

    <h2 class="center">Authenticate</h2>
    <div class="box">
        <form class="form" action="/{{ suffix }}" method="get">
            <div class="field is-horizontal">
                <div class="field-label is-normal">
                    <label class="label">Key:</label>
                </div>
                <div class="field-body">
                    <div class="field">
                        <p class="control is-expanded">
                            <input class="input" type="password" name="key">
                        </p>
                    </div>
                    <div class="field">
                        <p class="control is-expanded">
                            <button class="button is-primary" type="submit">Continue</button>
                        </p>
                    </div>
                </div>
            </div>
        </form>
    </div>
</div>
{% endblock %}