{% macro message(title, text, class="") %}
    &nbsp;
    <div class="container">
        <article class="message {{ class }}">
            <div class="message-header">
                <p>{{ title }}</p>
            </div>
            <div class="message-body">
                {{ text }}
            </div>
        </article>
    </div>
    &nbsp;
{% endmacro %}